/*
 * wiivdr.c: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include <vdr/menu.h>
#include <vdr/remote.h>
#include <vdr/plugin.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <wchar.h>
#include <wiimote.h>
#include <wiimote_api.h>
#include <wiimote_link.h>

#include "bewegung_reader.h"
#include "bewegung_analyse.h"
#include "bewegung_setup.h"
#include "bewegung_config.h"
#include "bewegung_mainmenu.h"

static const char *VERSION        = "0.0.2";
static const char *DESCRIPTION    = tr("Adds the wiimote for controlling vdr");
static const char *MAINMENUENTRY  = tr("Bewegung");

class cPluginBewegung : public cPlugin 
{
private:
  // Add any member variables or functions you may need here.
  cBewegungReaderThread *thread;
  cBewegungAnalyseThread *threadAnalyse;
public:
  cPluginBewegung(void);
  virtual ~cPluginBewegung();
  virtual const char *Version(void) { return VERSION; }
  virtual const char *Description(void) { return DESCRIPTION; }
  virtual const char *CommandLineHelp(void);
  virtual bool ProcessArgs(int argc, char *argv[]);
  virtual bool Initialize(void);
  virtual bool Start(void);
  virtual void Stop(void);
  virtual void Housekeeping(void);
  virtual void MainThreadHook(void);
  virtual cString Active(void);
  virtual time_t WakeupTime(void);
  virtual const char *MainMenuEntry(void) { return (bewegungConfig.hidemenu ? NULL : tr(MAINMENUENTRY)); }
  virtual cOsdObject *MainMenuAction(void);
  virtual cMenuSetupPage *SetupMenu(void);
  virtual bool SetupParse(const char *Name, const char *Value);
  virtual bool Service(const char *Id, void *Data = NULL);
  virtual const char **SVDRPHelpPages(void);
  virtual cString SVDRPCommand(const char *Command, const char *Option, int &ReplyCode);
  };

cPluginBewegung::cPluginBewegung(void)
{
  // Initialize any member variables here.
  // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
  // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
}

cPluginBewegung::~cPluginBewegung()
{
  // Clean up after yourself!
}

const char *cPluginBewegung::CommandLineHelp(void)
{
  // Return a string that describes all known command line options.
  return NULL;
}

bool cPluginBewegung::ProcessArgs(int argc, char *argv[])
{
  // Implement command line argument processing here if applicable.
  return true;
}

bool cPluginBewegung::Initialize(void)
{
  // Initialize any background activities the plugin shall perform.
  return true;
}

bool cPluginBewegung::Start(void)
{
  // Start any background activities the plugin shall perform.
  cBewegungReaderThread::Init();
  cBewegungAnalyseThread::Init();
  return true;
}

void cPluginBewegung::Stop(void)
{
  // Stop any background activities the plugin is performing.
  cBewegungReaderThread::Exit();
  cBewegungAnalyseThread::Exit();
}

void cPluginBewegung::Housekeeping(void)
{
  // Perform any cleanup or other regular tasks.
}

void cPluginBewegung::MainThreadHook(void)
{
  // Perform actions in the context of the main program thread.
  // WARNING: Use with great care - see PLUGINS.html!
}

cString cPluginBewegung::Active(void)
{
  // Return a message string if shutdown should be postponed
  return NULL;
}

time_t cPluginBewegung::WakeupTime(void)
{
  // Return custom wakeup time for shutdown script
  return 0;
}

cOsdObject *cPluginBewegung::MainMenuAction(void)
{
  // Perform the action when selected from the main VDR menu.

  return new cBewegungMainmenu;
}

cMenuSetupPage *cPluginBewegung::SetupMenu(void)
{
  // Return a setup menu in case the plugin supports one.
  return new cMenuSetupBewegung();
}

bool cPluginBewegung::SetupParse(const char *Name, const char *Value)
{
   // Parse your own setup parameters and store their values.

   if      (!strcasecmp(Name, "SleepTime"))     bewegungConfig.sleepTime = atoi(Value);
   else if (!strcasecmp(Name, "MACAddress"))    strn0cpy(bewegungConfig.macAddress, Value,sizeof(bewegungConfig.macAddress));
   else if (!strcasecmp(Name, "HideMenu"))      bewegungConfig.hidemenu       = atoi(Value);
   else if (!strcasecmp(Name, "EnableConnect")) bewegungConfig.enableConnect  = atoi(Value);
   else if (!strcasecmp(Name, "TiltUpDown"))    bewegungConfig.tiltUpDown     = atoi(Value);
   else if (!strcasecmp(Name, "TiltLeftRight")) bewegungConfig.tiltLeftRight  = atoi(Value);
   else
      return false;

   return true;
}

bool cPluginBewegung::Service(const char *Id, void *Data)
{
  // Handle custom service requests from other plugins
  return false;
}

const char **cPluginBewegung::SVDRPHelpPages(void)
{
  // Return help text for SVDRP commands this plugin implements
  return NULL;
}

cString cPluginBewegung::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
{
  // Process SVDRP commands this plugin implements
  return NULL;
}

VDRPLUGINCREATOR(cPluginBewegung) // Don't touch this!

