
#include <unistd.h>

#define _ENABLE_TILT
#include <wiimote.h>

#include <vdr/tools.h>
#include <vdr/plugin.h>

#include "bewegung_reader.h"
#include "bewegung_analyse.h"
#include "bewegung_setup.h"
#include "bewegung_config.h"


cBewegungAnalyseThread *cBewegungAnalyseThread::m_Instance = NULL;

cCondVar cBewegungAnalyseThread::update;

cBewegungAnalyseThread::cBewegungAnalyseThread()
   : cThread("bewegung: bewegungalyse")
{
   m_Active = false;
   m_lastUpdate = time(0);
   isyslog("[wiivdr] starting analyse-thread\n");
}

cBewegungAnalyseThread::~cBewegungAnalyseThread() 
{
   if (m_Active)
      Stop();
}

void cBewegungAnalyseThread::Init() 
{
   if (!m_Instance) 
   {
      m_Instance = new cBewegungAnalyseThread();
      m_Instance->Start();
   }
}

void cBewegungAnalyseThread::Exit(void) 
{
   if (m_Instance) 
   {
      m_Instance->Stop();
      DELETENULL(m_Instance);
   }
}

void cBewegungAnalyseThread::Stop(void) 
{
   m_Active = false;
   update.Broadcast();
   Cancel(6);
}

cBewegungAnalyseThread *cBewegungAnalyseThread::getInstance(void)
{
   return m_Instance;
}

void cBewegungAnalyseThread::reset(void)
{
   cBewegungReaderThread::motionValues.doPressOK         = false;
   cBewegungReaderThread::motionValues.doPressUp         = false;
   cBewegungReaderThread::motionValues.doPressDown       = false;
   cBewegungReaderThread::motionValues.doPressLeft       = false;
   cBewegungReaderThread::motionValues.doPressRight      = false;
   cBewegungReaderThread::motionValues.doPressBlue       = false;
   cBewegungReaderThread::motionValues.doPressGreen      = false;
   cBewegungReaderThread::motionValues.doPressRed        = false;
   cBewegungReaderThread::motionValues.doPressYellow     = false;
   cBewegungReaderThread::motionValues.doPressVolumeUp   = false;
   cBewegungReaderThread::motionValues.doPressVolumeDown = false;
   cBewegungReaderThread::motionValues.doPressMenu       = false;
   cBewegungReaderThread::motionValues.doPressBack       = false;
}

void cBewegungAnalyseThread::check(void) 
{
  if (cBewegungReaderThread::motionValues.doPressOK)
  {
    dsyslog("[wiivdr] doPressOK\n");
    cRemote::Put(kOk);
  }
  
  if (cBewegungReaderThread::motionValues.doPressUp)
  {
    dsyslog("[wiivdr] doPressUp\n");
    cRemote::Put(kUp);
  }
  
  if (cBewegungReaderThread::motionValues.doPressMenu)
  {
    dsyslog("[wiivdr] doPressMenu\n");
    cRemote::Put(kMenu);
  }
  
  if (cBewegungReaderThread::motionValues.doPressDown)
  {
    dsyslog("[wiivdr] doPressDown\n");
    cRemote::Put(kDown);
  }
  
  if (cBewegungReaderThread::motionValues.doPressRight)
  {
    dsyslog("[wiivdr] doPressRight\n");
    cRemote::Put(kRight);
  }
  
  if (cBewegungReaderThread::motionValues.doPressLeft)
  {
    dsyslog("[wiivdr] doPressLeft\n");
    cRemote::Put(kLeft);
  }
  
  if (cBewegungReaderThread::motionValues.doPressRed)
  {
    dsyslog("[wiivdr] doPressRed\n");
    cRemote::Put(kRed);
  }
  
  if (cBewegungReaderThread::motionValues.doPressGreen)
  {
    dsyslog("[wiivdr] doPressGreen\n");
    cRemote::Put(kGreen);
  }
  
  if (cBewegungReaderThread::motionValues.doPressYellow)
  {
    dsyslog("[wiivdr] doPressYellow\n");
    cRemote::Put(kYellow);
  }
  
  if (cBewegungReaderThread::motionValues.doPressBlue)
  {
    dsyslog("[wiivdr] doPressBlue\n");
    cRemote::Put(kBlue);
  }
  
  if (cBewegungReaderThread::motionValues.doPressBack)
  {
    dsyslog("[wiivdr] doPressBack\n");
    cRemote::Put(kBack);
  }
  
  if (cBewegungReaderThread::motionValues.doPressVolumeUp)
  {
    dsyslog("[wiivdr] doPressVolumeUp\n");
    cRemote::Put(kVolUp);
  }
  
  if (cBewegungReaderThread::motionValues.doPressVolumeDown)
  {
    dsyslog("[wiivdr] doPressVolumeDown\n");
    cRemote::Put(kVolDn);
  }
}

void cBewegungAnalyseThread::Action(void)
{
   m_Active = true;

   // let VDR do its startup

   mutex.Lock();       // mutex gets ONLY unlocked when sleeping

   while (m_Active) 
   {
      // wait for bewegung-thread events ...
     
      update.TimedWait(mutex, 6000);
    
      // process events

      check();
      reset();
   };

   // ?? m_Instance = NULL;
}
